@@ -1,6 +1,6 @@
 package Plack::App::FakeApache1::Constants;
 {
-  $Plack::App::FakeApache1::Constants::VERSION = '0.0.1_05';
+  $Plack::App::FakeApache1::Constants::VERSION = '0.0.2';
 }
 {
   $Plack::App::FakeApache1::Constants::DIST = 'Plack-App-FakeApache1';
@@ -40,6 +40,7 @@ use Sub::Exporter -setup => {
         HTTP_UNPROCESSABLE_ENTITY
         HTTP_LOCKED
         HTTP_FAILED_DEPENDENCY
+        HTTP_INTERNAL_SERVER_ERROR
     / ],
     groups => {
         default => [ qw/OK/ ],
@@ -70,6 +71,7 @@ use Sub::Exporter -setup => {
                         HTTP_LOCKED
                         HTTP_FAILED_DEPENDENCY
                      /],
+        '5xx'   => [ qw/HTTP_INTERNAL_SERVER_ERROR/ ],
     },
 };
 
@@ -105,6 +107,9 @@ sub HTTP_UNPROCESSABLE_ENTITY          { 422; }
 sub HTTP_LOCKED                        { 423; }
 sub HTTP_FAILED_DEPENDENCY             { 424; }
 
+# 5xx status codes
+sub HTTP_INTERNAL_SERVER_ERROR         { 500; }
+
 sub DONE        { -2; }
 sub DECLINED    { -1; }
 sub OK          {  0; }
@@ -113,6 +118,7 @@ sub REDIRECT    { HTTP_MOVED_TEMPORARILY; }
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -121,7 +127,7 @@ Plack::App::FakeApache1::Constants
 
 =head1 VERSION
 
-version 0.0.1_05
+version 0.0.2
 
 =head1 AUTHOR
 
@@ -135,4 +141,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
