@@ -1,6 +1,6 @@
 package Plack::App::FakeApache1::Handler;
 {
-  $Plack::App::FakeApache1::Handler::VERSION = '0.0.1_05';
+  $Plack::App::FakeApache1::Handler::VERSION = '0.0.2';
 }
 {
   $Plack::App::FakeApache1::Handler::DIST = 'Plack-App-FakeApache1';
@@ -8,6 +8,8 @@ package Plack::App::FakeApache1::Handler;
 use strict;
 use warnings;
 
+use Carp;
+
 # borrowed heavily from
 #  http://cpansearch.perl.org/src/MIYAGAWA/Plack-0.9946/lib/Plack/Handler/Apache2.pm
 
@@ -38,6 +40,9 @@ sub load_app {
 sub call_app {
     my ($class, $r, $app) = @_;
 
+    Carp::croak('$app is undefined')
+        unless defined $app;
+
     $r->subprocess_env; # let Apache create %ENV for us :)
 
     my $env = {
@@ -137,6 +142,7 @@ sub _handle_response {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -145,7 +151,7 @@ Plack::App::FakeApache1::Handler
 
 =head1 VERSION
 
-version 0.0.1_05
+version 0.0.2
 
 =head1 AUTHOR
 
@@ -159,4 +165,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
