@@ -1,11 +1,11 @@
 package Plack::App::FakeModPerl1::Server;
 {
-  $Plack::App::FakeModPerl1::Server::VERSION = '0.0.1_05';
+  $Plack::App::FakeModPerl1::Server::VERSION = '0.0.2';
 }
 {
   $Plack::App::FakeModPerl1::Server::DIST = 'Plack-App-FakeApache1';
 }
-use feature ':5.10';
+use 5.10.1;
 use Carp;
 
 sub new {
@@ -35,6 +35,7 @@ sub dir_config {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -43,7 +44,7 @@ Plack::App::FakeModPerl1::Server
 
 =head1 VERSION
 
-version 0.0.1_05
+version 0.0.2
 
 =head1 AUTHOR
 
@@ -57,4 +58,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
